API Reference
====================================

Data Rules
----------

.. automodule:: metadata_guardian.data_rules
    :members:


Scanner
-------

.. automodule:: metadata_guardian.scanner
    :members:

Report
-------

.. automodule:: metadata_guardian.report
    :members:


Source
------

.. automodule:: metadata_guardian.source.metadata_source
    :members:

Local Sources
-------------

.. automodule:: metadata_guardian.source.local.avro_source
    :members:

.. automodule:: metadata_guardian.source.local.local_metadata_source
    :members:

.. automodule:: metadata_guardian.source.local.parquet_source
    :members:

External Sources
----------------

.. automodule:: metadata_guardian.source.external.aws_source
    :members:

.. automodule:: metadata_guardian.source.external.deltatable_source
    :members:

.. automodule:: metadata_guardian.source.external.external_metadata_source
    :members:

.. automodule:: metadata_guardian.source.external.gcp_source
    :members:

.. automodule:: metadata_guardian.source.external.snowflake_source
    :members: